@@ -22,7 +22,6 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from enum import auto
 from typing import Tuple
 
 from .errors import Error
@@ -38,7 +37,7 @@ class CustomizableBase:
     self.locale = locale
 
   @property
-  def unit(self) -> auto:
+  def unit(self) -> _Unit:
     """The measuring unit used to display information in this object."""
 
     return self.__unit
@@ -68,9 +67,9 @@ class CustomizableBase:
     """
     Sets the default localization used to display information in this object.
 
-    :param to: The new :class:`Locale` to be used to display information in this object.
+    :param to: The new :class:`~python_weather.enums.Locale` to be used to display information in this object.
     :type to: Locale
-    :exception Error: If the ``to`` argument is not a part of the :class:`Locale` enum.
+    :exception Error: If the ``to`` argument is not a part of the :class:`~python_weather.enums.Locale` enum.
     """
 
     if not isinstance(to, Locale):
@@ -79,84 +78,71 @@ class CustomizableBase:
     self.__locale = to
 
 
-class BaseForecast(CustomizableBase):
-  __slots__: Tuple[str, ...] = ('__inner',)
+class BaseForecast:
+  __slots__: Tuple[str, ...] = (
+    'ultraviolet',
+    'humidity',
+    'wind_direction',
+    'kind',
+    'feels_like',
+    'temperature',
+    'precipitation',
+    'pressure',
+    'visibility',
+    'wind_speed',
+    'description',
+  )
+
+  ultraviolet: UltraViolet
+  """The ultra-violet (UV) index."""
+
+  humidity: int
+  """The humidity value in percent."""
+
+  wind_direction: WindDirection
+  """The wind direction."""
+
+  kind: Kind
+  """The kind of the forecast."""
+
+  feels_like: int
+  """What it felt like, in celcius or fahrenheit."""
+
+  temperature: int
+  """The temperature in either celcius or Fahrenheit."""
+
+  precipitation: float
+  """The precipitation in either millimeters or inches."""
+
+  pressure: float
+  """The pressure in either pascal or inches."""
+
+  visibility: int
+  """The visibility distance in either kilometers or miles."""
+
+  wind_speed: int
+  """The wind speeds in either kilometers/hour or miles/hour."""
+
+  description: str
+  """The description regarding the forecast. This can be localized in different languages depending on the localization used."""
 
   def __init__(self, json: dict, unit: _Unit, locale: Locale):
-    self.__inner = json
-
-    super().__init__(unit, locale)
-
-  @property
-  def ultraviolet(self) -> UltraViolet:
-    """The ultra-violet (UV) index."""
-
-    return UltraViolet._new(int(self.__inner['uvIndex']))
-
-  @property
-  def feels_like(self) -> int:
-    """What it felt like, in celcius or fahrenheit."""
-
-    return int(self.__inner[f'FeelsLike{self._CustomizableBase__unit.temperature}'])
-
-  @property
-  def humidity(self) -> int:
-    """The humidity value in percent."""
-
-    return int(self.__inner['humidity'])
-
-  @property
-  def temperature(self) -> int:
-    """The temperature in either celcius or Fahrenheit."""
-
-    return int(self.__inner[f'temp_{self._CustomizableBase__unit.temperature}'])
-
-  @property
-  def precipitation(self) -> float:
-    """The precipitation in either millimeters or inches."""
-
-    return float(self.__inner[f'precip{self._CustomizableBase__unit.precipitation}'])
-
-  @property
-  def pressure(self) -> float:
-    """The pressure in either pascal or inches."""
-
-    return float(self.__inner[f'pressure{self._CustomizableBase__unit.pressure}'])
-
-  @property
-  def visibility(self) -> int:
-    """The visibility distance in either kilometers or miles."""
-
-    return int(self.__inner[f'visibility{self._CustomizableBase__unit.visibility}'])
-
-  @property
-  def wind_speed(self) -> int:
-    """The wind speeds in either kilometers/hour or miles/hour."""
-
-    return int(self.__inner[f'windspeed{self._CustomizableBase__unit.velocity}'])
-
-  @property
-  def wind_direction(self) -> WindDirection:
-    """The wind direction."""
-
-    return WindDirection._new(
-      self.__inner['winddir16Point'], int(self.__inner['winddirDegree'])
-    )
-
-  @property
-  def description(self) -> str:
-    """The description regarding the forecast. This can be localized in different languages depending on the localization used."""
-
     description = (
-      self.__inner['weatherDesc'][0]['value']
-      if self._CustomizableBase__locale == Locale.ENGLISH
-      else self.__inner[f'lang_{self._CustomizableBase__locale.value}'][0]['value']
+      json['weatherDesc'][0]['value']
+      if locale is Locale.ENGLISH
+      else json[f'lang_{locale.value}'][0]['value']
     )
 
-    return description.strip()
-
-  @property
-  def kind(self) -> Kind:
-    """The kind of the forecast."""
-
-    return Kind(int(self.__inner['weatherCode']))
+    self.ultraviolet = UltraViolet._new(int(json['uvIndex']))
+    self.humidity = int(json['humidity'])
+    self.wind_direction = WindDirection._new(
+      json['winddir16Point'], int(json['winddirDegree'])
+    )
+    self.kind = Kind(int(json['weatherCode']))
+    self.feels_like = int(json[f'FeelsLike{unit.temperature}'])
+    self.temperature = int(json[f'temp_{unit.temperature}'])
+    self.precipitation = float(json[f'precip{unit.precipitation}'])
+    self.pressure = float(json[f'pressure{unit.pressure}'])
+    self.visibility = int(json[f'visibility{unit.visibility}'])
+    self.wind_speed = int(json[f'windspeed{unit.velocity}'])
+    self.description = description.strip()
